
# Slot: elseconditions


an expression that must hold for an instance of the class, if the preconditions no not hold

URI: [linkml:elseconditions](https://w3id.org/linkml/elseconditions)


## Domain and Range

None &#8594;  <sub>0..1</sub> [AnonymousClassExpression](AnonymousClassExpression.md)

## Parents


## Children


## Used by

 * [ClassRule](ClassRule.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Aliases:** | | else |

